# AskQuora

Quora Q&amp;A right from the command line!

<img src="http://i.imgur.com/Bu7AXPA.png">

## Installation & Usage:

`sudo pip install -U askquora`

or if you like to live on the bleeding edge: `sudo python setup.py install`

Run it using `askquora`

## Contributing:

Any PR's in bug fixes, features or even this documentation are most welcome!

## Disclaimer:

This is not an official Quora product.

## License:

`The MIT License`
